#!/usr/bin/python

import qi
import paramiko
import os
import argparse


ROBOT_DEF_URL = "192.168.0.10"
ROBOT_DEF_SSH = "pepper"

def ssh_connect (ssh):
    client = paramiko.SSHClient()
    client._policy = paramiko.WarningPolicy()
    client.set_missing_host_key_policy(paramiko.AutoAddPolicy())

    ssh_config = paramiko.SSHConfig()
    user_config_file = os.path.expanduser("~/.ssh/config")
    if os.path.exists(user_config_file):
        with open(user_config_file) as f:
            ssh_config.parse(f)
            cfg = {'hostname': ssh, 'username': "nao"}
            user_config = ssh_config.lookup(cfg['hostname'])
            for k in ('hostname', 'username', 'port', 'identityfile'):
                if k in user_config:
                    if k == 'identityfile':
                        cfg['key_filename'] = user_config['identityfile']
                    else:
                        cfg[k] = user_config[k]

                if 'proxycommand' in user_config:
                    cfg['sock'] = paramiko.ProxyCommand(user_config['proxycommand'])
    client.connect(**cfg)
    return (client)

def main(ip, port, ssh, packages = []):

    if ssh is None: ssh = ip
    sshc = ssh_connect(ssh)
    sftp = sshc.open_sftp()
    for pkg_file in packages:
        pkg_path = os.path.abspath(pkg_file)
        pkg_file = os.path.basename(pkg_file)
        print "Uploading PKG {} as {}".format(pkg_path,pkg_file)
        sftp.put(pkg_path, pkg_file)
        print "Connecting NAOqi session"
        app = qi.Application(url='tcp://'+ip+':'+str(port))
        app.start()
        session = app.session

        print "Installing app {}".format(pkg_file)
        packagemgr = session.service("PackageManager")
        packagemgr.install("/home/nao/"+pkg_file)

        print "Cleaning PKG"
        sftp.remove(pkg_file)

    print "End"
    sftp.close()
    sshc.close()
    app.stop()

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--ip", type=str, default=ROBOT_DEF_URL, help="Robot IP address")
    parser.add_argument("--port", type=int, default=9559, help="Robot port number")
    parser.add_argument("--ssh", type=str, default=ROBOT_DEF_SSH, help="Robot SSH hostname")
    parser.add_argument('packages', nargs='*', help="Package to install")

    args = parser.parse_args()
    main(args.ip, args.port, args.ssh, args.packages)

